package dk.sdu.imada.jkkn04.Protein.cmd;

import java.io.IOException;
import java.util.Map;

import dk.sdu.imada.jkkn04.Protein.data.ProteinMap;
import dk.sdu.imada.jkkn04.Protein.data.ProteinMapCollection;
import dk.sdu.imada.jkkn04.Protein.data.SequenceTranslated;
import dk.sdu.imada.jkkn04.Protein.data.SequenceType;
import dk.sdu.imada.jkkn04.Protein.tests.AbstractEvaluation;
import dk.sdu.imada.jkkn04.Protein.util.ProcessUtil;
import dk.sdu.imada.jkkn04.Protein.util.ProcessUtil.MultipleEvaluationsMap;
import dk.sdu.imada.jkkn04.Protein.util.ProcessUtil.ObservationPredictionMap;

/**
 * Commandline program to compare all combinations of predictors and observed sequences of
 * a given type
 * 
 * @author Kristian Krmmer Nielsen <jkkn@jkkn.dk>
 */
public class CompareAllCombinations {

	/**
	 * Main method - this runs a comparition of all combinations of predictors and
	 * observed sequences
	 * 
	 * @param args Not used
	 */
	public static void main(final String[] args) {

		try {
			final ProteinMapCollection pmc = new ProteinMapCollection("cytokines/");

			final ObservationPredictionMap sum = new ObservationPredictionMap();
			/* list each protein for every file by protein */
			for (final String proteinId : pmc.getProteinIdentifiers()) {

				final ProteinMap pm = pmc.getProteinMap(proteinId);
				/* first description */
				final String description = pm.values().iterator().next().getDescription();
				System.out.println("Processing for \"" + description + "\":");
				final ObservationPredictionMap results = ProcessUtil
						.performAllTestsByType(pm, SequenceType.OBSERVATION_TYPES,
								SequenceType.PREDICTION_TYPES);

				printResults(results);
				System.out.println();
				ProcessUtil.summerizeAll(sum, results);
			}

			System.out.println("SUMMARIZE:");
			printResults(sum);

		} catch (final IOException e) {
			e.printStackTrace();
		}
	}

	private static void printResults(final ObservationPredictionMap results) {
		for (final Map.Entry<SequenceTranslated, Map<SequenceTranslated, MultipleEvaluationsMap>> observed : results
				.entrySet()) {
			final SequenceTranslated observedType = observed.getKey();
			for (final Map.Entry<SequenceTranslated, MultipleEvaluationsMap> prediction : observed
					.getValue().entrySet()) {
				final SequenceTranslated predictionType = prediction.getKey();
				for (final Map.Entry<String, AbstractEvaluation> evaluation : prediction
						.getValue().entrySet()) {

					// ((StateMachine)evaluation.getValue()).printDebug();

					System.out.println(String.format("%s -> %s (%s):", observedType
							.name(), predictionType.name(), evaluation.getKey()));
					for (final Map.Entry<String, Object> result : evaluation.getValue()
							.getResults().entrySet()) {
						System.out.println(String.format("   %s = %s", result.getKey(),
								result.getValue().toString()));
					}
				}
			}
		}
	}

}
