package dk.sdu.imada.jkkn04.Protein.cmd;

import java.io.IOException;

import dk.sdu.imada.jkkn04.Protein.data.Protein;
import dk.sdu.imada.jkkn04.Protein.data.ProteinMap;
import dk.sdu.imada.jkkn04.Protein.data.ProteinMapCollection;
import dk.sdu.imada.jkkn04.Protein.data.SequenceTranslated;
import dk.sdu.imada.jkkn04.Protein.data.SequenceType;
import dk.sdu.imada.jkkn04.Protein.data.Protein.TranslationType;

/**
 * Commandline program to lists all protein sequences after translation
 * 
 * @author Kristian Krmmer Nielsen <jkkn@jkkn.dk>
 */
public class ListAllProteins {

	/**
	 * Main method - lists all protein sequences after translation
	 * 
	 * @param args Not used
	 */
	public static void main(final String[] args) {

		try {
			final ProteinMapCollection pmc = new ProteinMapCollection("chymotrypsins/");
			// ProteinMapCollection pmc = new
			// ProteinMapCollection("cytokines/");

			/* list each protein for every file by protein */
			for (final String proteinId : pmc.getProteinIdentifiers()) {
				// String proteinId = "1INR__";

				final ProteinMap pm = pmc.getProteinMap(proteinId);
				for (final SequenceType seqType : SequenceType.values()) {
					for (final TranslationType transType : TranslationType.values()) {
						final SequenceTranslated st = new SequenceTranslated(seqType,
								transType);
						if (pm.containsKey(st)) {
							final Protein p = pm.get(st);
							final String sequence = p.getSequenceType().isObservation() ? p
									.getCleanSequence()
									: p.getSequence();
							System.out.println(String.format("%-34s %s", p
									.getIdentifier()
									+ " ("
									+ p.getSequenceType()
									+ "/"
									+ p.getTranslationType() + "):", sequence));
						}
					}
				}

				System.out.println();
			}

		} catch (final IOException e) {
			e.printStackTrace();
		}

	}

}
