package dk.sdu.imada.jkkn04.Protein.data;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import dk.sdu.imada.jkkn04.Protein.data.Protein.TranslationType;

/**
 * Represents a file containing sequence data for a specific prediction/observation type
 * 
 * @author Kristian Krmmer Nielsen <jkkn@jkkn.dk>
 */
public class ProteinFile {

	final private URL file;
	final private Map<String, Protein> proteins;

	/**
	 * Creates a new instance for the given file/resource
	 * 
	 * @param file Resource to use
	 * @throws IOException In case of read-error
	 */
	public ProteinFile(final URL file) throws IOException {
		super();
		this.file = file;
		proteins = readFile(detectPredictionType());
	}

	private SequenceType detectPredictionType() {
		final String filename = file.getFile().toUpperCase();
		for (final SequenceType t : SequenceType.values()) {
			if (filename.contains(t.name()))
				return t;
		}
		return SequenceType.PRIMARY;
	}

	private Map<String, Protein> readFile(final SequenceType predictionType)
			throws IOException {
		final BufferedReader bf = new BufferedReader(new InputStreamReader(file
				.openStream()));

		final Map<String, Protein> proteins = new HashMap<String, Protein>();

		String currentProteinId = null;
		StringBuffer currentProtein = null;
		String line;
		while ((line = bf.readLine()) != null) {
			if (line.startsWith(">")) {
				if (currentProteinId != null && currentProtein != null) {
					/*
					 * if (currentProtein.length() == 0) { // format error }
					 */
					final Protein p = new Protein(currentProteinId, currentProtein
							.toString(), predictionType, TranslationType.RAW);
					proteins.put(p.getIdentifier(), p);
				}
				currentProteinId = line.substring(1);
				currentProtein = new StringBuffer();
			} else {
				if (currentProtein != null) {
					currentProtein.append(line);
				} else {
					// format error
				}
			}
		}

		if (currentProteinId != null && currentProtein != null) {
			final Protein p = new Protein(currentProteinId, currentProtein.toString(),
					predictionType, TranslationType.RAW);
			proteins.put(p.getIdentifier(), p);
		}

		bf.close();

		return proteins;
	}

	/**
	 * Returns the read protein map.
	 * 
	 * @return map of proteins in file.
	 */
	public Map<String, Protein> getProteins() {
		return proteins;
	}

}
